@@ -123,7 +123,7 @@ TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::
     setUndoRedoEnabled(false);
     setAcceptRichText(false);
 
-#ifndef NOKDE
+#if !defined(NOKDE) || defined(SONNET_STATIC)
     m_highlighter->setActive(m_enabled);
     setHighlighter(m_highlighter);
 #endif
@@ -141,7 +141,7 @@ void TranslationUnitTextEdit::setSpellCheckingEnabled(bool enable)
 {
     Settings::setAutoSpellcheck(enable);
     m_enabled=enable;
-#ifndef NOKDE
+#if !defined(NOKDE) || defined(SONNET_STATIC)
     m_highlighter->setActive(enable);
 #endif
     SettingsController::instance()->dirty=true;
@@ -153,12 +153,14 @@ void TranslationUnitTextEdit::fileLoaded()
     QString langCode=m_part==DocPosition::Source? m_catalog->sourceLangCode():m_catalog->targetLangCode();
 
     QLocale langLocale(langCode);
-#ifndef NOKDE
+#if !defined(NOKDE) || defined(SONNET_STATIC)
     // First try to use a locale name derived from the language code
     m_highlighter->setCurrentLanguage(langLocale.name());
     // If that fails, try to use the language code directly
-    if (m_highlighter->currentLanguage().isEmpty()) {
+    if (m_highlighter->currentLanguage()!=langLocale.name() || m_highlighter->currentLanguage().isEmpty()) {
         m_highlighter->setCurrentLanguage(langCode);
+        if (m_highlighter->currentLanguage()!=langCode && langCode.length()>2)
+            m_highlighter->setCurrentLanguage(langCode.left(2));
     }
 #endif
     //"i use an english locale while translating kde pot files from english to hebrew" Bug #181989
@@ -334,7 +336,6 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
 
     QMap<int,int> posToTag;
     int i=catStr.tags.size();
-    //qDebug()<<"size:"<<i;
     while(--i>=0)
     {
         //qDebug()<<"\t"<<catStr.tags.at(i).getElementName()<<catStr.tags.at(i).id<<catStr.tags.at(i).start<<catStr.tags.at(i).end;
@@ -435,7 +436,7 @@ void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int
 
 
     const QString& editText=toPlainText();
-    if (KDE_ISUNLIKELY( m_currentPos.entry==-1 || editText==_oldMsgstr ))
+    if (Q_UNLIKELY( m_currentPos.entry==-1 || editText==_oldMsgstr ))
     {
         //qWarning()<<"stopping"<<m_currentPos.entry<<editText<<_oldMsgstr;
         return;
@@ -541,7 +542,7 @@ void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int
 
 bool TranslationUnitTextEdit::removeTargetSubstring(int delStart, int delLen, bool refresh)
 {
-    if (KDE_ISUNLIKELY( m_currentPos.entry==-1 ))
+    if (Q_UNLIKELY( m_currentPos.entry==-1 ))
         return false;
 
     if (!::removeTargetSubstring(m_catalog, m_currentPos, delStart, delLen))
@@ -673,7 +674,7 @@ void TranslationUnitTextEdit::insertFromMimeData(const QMimeData* source)
         //sets right cursor position implicitly -- needed for mouse paste
         {
             QMimeData mimeData;
-            mimeData.setText("");
+            mimeData.setText(QString());
             KTextEdit::insertFromMimeData(&mimeData);
             start=textCursor().position();
         }
@@ -789,7 +790,7 @@ void TranslationUnitTextEdit::keyPressEvent(QKeyEvent *keyEvent)
         //only for cases when:
         //-BkSpace was hit and cursor was atStart
         //-Del was hit and cursor was atEnd
-        if (KDE_ISUNLIKELY( !m_catalog->isApproved(m_currentPos.entry) && !textCursor().hasSelection() )
+        if (Q_UNLIKELY( !m_catalog->isApproved(m_currentPos.entry) && !textCursor().hasSelection() )
                             && ((textCursor().atStart()&&keyEvent->key()==Qt::Key_Backspace)
                                  ||(textCursor().atEnd()&&keyEvent->key()==Qt::Key_Delete) ))
             requestToggleApprovement();
@@ -956,7 +957,7 @@ void TranslationUnitTextEdit::insertTag(InlineTag tag)
     QTextCursor cursor=textCursor();
     tag.start=qMin(cursor.anchor(),cursor.position());
     tag.end=qMax(cursor.anchor(),cursor.position())+tag.isPaired();
-    qDebug()<<(m_part==DocPosition::Source)<<tag.start<<tag.end;
+    qDebug()<<"insert tag"<<(m_part==DocPosition::Source)<<tag.start<<tag.end;
     m_catalog->push(new InsTagCmd(m_catalog,currentPos(),tag));
     showPos(currentPos(),CatalogString(),/*keepCursor*/true);
     cursor.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,tag.end+1+tag.isPaired());
@@ -965,6 +966,7 @@ void TranslationUnitTextEdit::insertTag(InlineTag tag)
 
 int TranslationUnitTextEdit::strForMicePosIfUnderTag(QPoint mice, CatalogString& str, bool tryHarder)
 {
+    if (m_currentPos.entry==-1) return -1;
     QTextCursor cursor=cursorForPosition(mice);
     int pos=cursor.position();
     str=m_catalog->catalogString(m_currentPos);
@@ -1154,7 +1156,7 @@ bool TranslationUnitTextEdit::event(QEvent *event)
             return true;
         }
 
-#ifndef NOKDE
+#if !defined(NOKDE) || defined(SONNET_STATIC)
         QString tip;
 
         QString langCode=m_highlighter->currentLanguage();
@@ -1162,9 +1164,9 @@ bool TranslationUnitTextEdit::event(QEvent *event)
         if (nospell)
             langCode=m_part==DocPosition::Source?m_catalog->sourceLangCode():m_catalog->targetLangCode();
         QLocale l(langCode);
-        if (l.language()!=QLocale::C) tip=l.nativeLanguageName()+QLatin1String(" (");
+        if (l.language()!=QLocale::C) tip = l.nativeLanguageName() + QLatin1String(" (");
         tip+=langCode;
-        if (l.language()!=QLocale::C) tip +=')';
+        if (l.language()!=QLocale::C) tip += ')';
         if (nospell)
             tip+=QLatin1String(" - ")%i18n("no spellcheck available");
         QToolTip::showText(helpEvent->globalPos(), tip);
@@ -1212,7 +1214,7 @@ void TranslationUnitTextEdit::doTag(bool immediate)
     }
     else
     {
-        if (KDE_ISUNLIKELY( Project::instance()->markup().isEmpty() ))
+        if (Q_UNLIKELY( Project::instance()->markup().isEmpty() ))
             return;
 
         //QRegExp tag("(<[^>]*>)+|\\&\\w+\\;");
@@ -1268,14 +1270,14 @@ void TranslationUnitTextEdit::source2target()
     {
         if (!document()->toPlainText().split(delimiter).contains(Settings::authorLocalizedName())) {
             if (!document()->isEmpty())
-                out=", ";
+                out=QLatin1String(", ");
             out+=Settings::authorLocalizedName();
         }
     }
     else if( ctxt.startsWith( QLatin1String("EMAIL OF TRANSLATORS") ) || text.startsWith( QLatin1String("_: EMAIL OF TRANSLATORS\\n") )) {
         if (!document()->toPlainText().split(delimiter).contains(Settings::authorEmail())) {
             if (!document()->isEmpty())
-                out=", ";
+                out=QLatin1String(", ");
             out+=Settings::authorEmail();
         }
     }
@@ -1367,6 +1369,7 @@ void TranslationUnitTextEdit::doCompletion(int pos)
         if (!m_completionBox->isVisible()) //NOTE remove the check if kdelibs gets adapted
             m_completionBox->show();
         m_completionBox->resize(m_completionBox->sizeHint());
+        qDebug()<<viewport()->mapToGlobal(cursorRect().bottomRight());
         m_completionBox->move(viewport()->mapToGlobal(cursorRect().bottomRight()));
     }
     else
